@@ -4,7 +4,7 @@
 ## Copyright (C) 2015 Pavol Bauer
 ## Copyright (C) 2017 -- 2019 Robin Eriksson
 ## Copyright (C) 2015 -- 2019 Stefan Engblom
-## Copyright (C) 2015 -- 2022 Stefan Widgren
+## Copyright (C) 2015 -- 2023 Stefan Widgren
 ##
 ## SimInf is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -47,9 +47,13 @@
 ##' @include check_arguments.R
 ##' @include SimInf_model.R
 ##' @export
-##' @importFrom methods as
-##' @importFrom Matrix sparseMatrix
 ##' @examples
+##' ## For reproducibility, call the set.seed() function and specify
+##' ## the number of threads to use. To use all available threads,
+##' ## remove the set_num_threads() call.
+##' set.seed(123)
+##' set_num_threads(1)
+##'
 ##' ## Create an 'SIR' model with 6 nodes and initialize it to run over 10 days.
 ##' u0 <- data.frame(S = 100:105, I = 1:6, R = rep(0, 6))
 ##' model <- SIR(u0 = u0, tspan = 1:10, beta = 0.16, gamma = 0.077)
@@ -126,7 +130,7 @@ setMethod(
         model@V <- template$dense
         model@V_sparse <- template$sparse
 
-        validObject(model)
+        methods::validObject(model)
         model
     }
 )
@@ -145,7 +149,7 @@ setMethod(
 create_template <- function(value, tspan, nodes, compartments, data) {
     if (is.null(value)) {
         dense <- matrix(data = data, nrow = 0, ncol = 0)
-        sparse <- new("dgCMatrix")
+        sparse <- methods::new("dgCMatrix")
         return(list(dense = dense, sparse = sparse))
     }
 
@@ -155,8 +159,8 @@ create_template <- function(value, tspan, nodes, compartments, data) {
     if (nrow(value) == 0) {
         dense <- matrix(data = data, nrow = 0, ncol = 0)
         dims <- c(length(nodes) * length(compartments), length(tspan))
-        sparse <- sparseMatrix(i = numeric(0), j = numeric(0),
-                               x = NA_real_, dims = dims)
+        sparse <- Matrix::sparseMatrix(i = numeric(0), j = numeric(0),
+                                       x = NA_real_, dims = dims)
         return(list(dense = dense, sparse = sparse))
     }
 
@@ -207,10 +211,11 @@ create_template <- function(value, tspan, nodes, compartments, data) {
         d1_times_d2 <- as.numeric(dims[1]) * as.numeric(dims[2])
         if (sum(value, na.rm = TRUE) == d1_times_d2) {
             dense <- matrix(data = data, nrow = 0, ncol = 0)
-            sparse <- new("dgCMatrix")
+            sparse <- methods::new("dgCMatrix")
         } else {
             dense <- matrix(data = data, nrow = 0, ncol = 0)
-            sparse <- sparseMatrix(i = i, j = j, x = NA_real_, dims = dims)
+            sparse <- Matrix::sparseMatrix(i = i, j = j, x = NA_real_,
+                                           dims = dims)
         }
 
         return(list(dense = dense, sparse = sparse))
@@ -218,7 +223,7 @@ create_template <- function(value, tspan, nodes, compartments, data) {
 
     dense <- matrix(data = data, nrow = 0, ncol = 0)
     dims <- c(length(nodes) * length(compartments), length(tspan))
-    sparse <- sparseMatrix(i = numeric(0), j = numeric(0),
-                           x = NA_real_, dims = dims)
+    sparse <- Matrix::sparseMatrix(i = numeric(0), j = numeric(0),
+                                   x = NA_real_, dims = dims)
     list(dense = dense, sparse = sparse)
 }
