@@ -1,7 +1,7 @@
 ## This file is part of SimInf, a framework for stochastic
 ## disease spread simulations.
 ##
-## Copyright (C) 2015 -- 2023 Stefan Widgren
+## Copyright (C) 2015 -- 2024 Stefan Widgren
 ##
 ## SimInf is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -50,65 +50,110 @@ setMethod(
     }
 )
 
+u0_target <- function(u0, target) {
+    if (is.null(target))
+        return(u0)
+
+    if (target %in% c("SISe3", "SISe3_sp")) {
+        u0$I_1 <- 0L
+        u0$I_2 <- 0L
+        u0$I_3 <- 0L
+        return(u0)
+    }
+
+    if (target %in% c("SIS", "SISe", "SISe_sp")) {
+        colnames(u0) <- c("key", "node", "S")
+        u0$I <- 0L
+        return(u0)
+    }
+
+    if (target %in% c("SIR")) {
+        colnames(u0) <- c("key", "node", "S")
+        u0$I <- 0L
+        u0$R <- 0L
+        return(u0)
+    }
+
+    if (target %in% c("SEIR")) {
+        colnames(u0) <- c("key", "node", "S")
+        u0$E <- 0L
+        u0$I <- 0L
+        u0$R <- 0L
+        return(u0)
+    }
+
+    stop("Invalid 'target' for 'u0'.", call. = FALSE)
+}
+
 ##' @rdname u0
-##' @param time the time-point that will be used to create u0. If left
-##'     empty (the default), the earliest time among the events will
-##'     be used.
-##' @param target the SimInf model ('SEIR', 'SIR', 'SIS', 'SISe3',
-##'     'SISe3_sp', 'SISe', or 'SISe_sp') to target the events and u0
-##'     for. The default, \code{NULL}, creates an \code{u0}, but where
-##'     the compartments might have to be renamed and post-processed
-##'     to fit the specific use case.
-##' @param age FIXME.
+##' @param time Only used when object is of class
+##'     \code{SimInf_indiv_events} object. The time-point that will be
+##'     used to create u0. If left empty (the default), the earliest
+##'     time among the events will be used.
+##' @param target Only used when object is of class
+##'     \code{SimInf_indiv_events} object. The SimInf model ('SEIR',
+##'     'SIR', 'SIS', 'SISe3', 'SISe3_sp', 'SISe', or 'SISe_sp') to
+##'     target the events and u0 for. The default, \code{NULL},
+##'     creates an \code{u0}, but where the compartments might have to
+##'     be renamed and post-processed to fit the specific use case.
+##' @param age Only used when object is of class
+##'     \code{SimInf_indiv_events} object. An integer vector with
+##'     break points in days for the ageing events. The default,
+##'     \code{NULL}, creates an \code{u0} where all individuals belong
+##'     to the same age category.
 ##' @export
 setMethod(
     "u0",
     signature(object = "SimInf_indiv_events"),
     function(object, time = NULL, target = NULL, age = NULL) {
-        ## Check for valid target model.
-        if (!is.null(target)) {
-            target <- match.arg(target, c("SEIR", "SIR", "SIS",
-                                          "SISe3", "SISe3_sp", "SISe",
-                                          "SISe_sp"))
-        }
-
-        if (is.null(age)) {
-            age <- c(0, Inf)
-        } else {
-            stop("Not implemented.")
-        }
+        age <- check_age(age)
+        target <- check_target(target, age)
 
         ## Determine the location and age for all individuals.
         individuals <- get_individuals(object, time)
 
         ## Ensure all nodes are included in u0.
-        nodes <- setdiff(c(object@node, object@dest), individuals$node)
-        nodes <- nodes[!is.na(nodes)]
-        node <- c(individuals$node, nodes)
+        all_nodes <- unique(c(object@node, object@dest))
+        all_nodes <- all_nodes[!is.na(all_nodes)]
+        missing_nodes <- setdiff(all_nodes, individuals$node)
+        S_columns <- paste0("S_", seq_len(length(age)))
 
         if (nrow(individuals)) {
             ## Determine the age categories.
             age_category <- paste0("S_", findInterval(individuals$age, age))
-            age_category <- c(age_category, rep(NA_character_, length(nodes)))
+            age_category <- c(age_category,
+                              rep(NA_character_, length(missing_nodes)))
 
             ## Create u0.
-            u0 <- as.data.frame.matrix(table(node, age_category))
+            nodes <- c(individuals$node, missing_nodes)
+            u0 <- as.data.frame.matrix(table(nodes, age_category))
+
+            ## Ensure all age categories exist in u0
+            age_category <- setdiff(S_columns, colnames(u0))
+            if (length(age_category)) {
+                u0 <- cbind(u0,
+                            matrix(data = 0L,
+                                   nrow = length(all_nodes),
+                                   ncol = length(age_category),
+                                   dimnames = list(NULL, age_category)))
+            }
         } else {
             ## Create an empty u0.
             u0 <- as.data.frame.matrix(
                 matrix(data = 0L,
-                       nrow = length(nodes),
-                       ncol = length(age) - 1,
-                       dimnames = list(
-                           nodes,
-                           paste0("S_", seq_len(length(age) - 1)))))
+                       nrow = length(all_nodes),
+                       ncol = length(age),
+                       dimnames = list(all_nodes, S_columns)))
         }
 
-        u0 <- cbind(node = rownames(u0), u0)
-        mode(u0$node) <- mode(node)
+        u0 <- cbind(key = rownames(u0), u0)
+        mode(u0$key) <- mode(all_nodes)
         rownames(u0) <- NULL
+        u0 <- u0[order(u0$key), ]
+        u0$node <- seq_len(nrow(u0))
+        u0 <- u0[, c("key", "node", S_columns), drop = FALSE]
 
-        u0
+        u0_target(u0, target)
     }
 )
 
