@@ -5,7 +5,7 @@
  * Copyright (C) 2015 Pavol Bauer
  * Copyright (C) 2017 -- 2019 Robin Eriksson
  * Copyright (C) 2015 -- 2019 Stefan Engblom
- * Copyright (C) 2015 -- 2019 Stefan Widgren
+ * Copyright (C) 2015 -- 2023 Stefan Widgren
  *
  * SimInf is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #ifndef INCLUDE_SIMINF_ARGS_H
 #define INCLUDE_SIMINF_ARGS_H
 
-#include <Rdefines.h>
+#include <Rinternals.h>
 
 int SimInf_arg_check_dgCMatrix(SEXP arg);
 int SimInf_arg_check_integer(SEXP arg);
