@@ -5,7 +5,7 @@
  * Copyright (C) 2015 Pavol Bauer
  * Copyright (C) 2017 -- 2019 Robin Eriksson
  * Copyright (C) 2015 -- 2019 Stefan Engblom
- * Copyright (C) 2015 -- 2020 Stefan Widgren
+ * Copyright (C) 2015 -- 2022 Stefan Widgren
  *
  * SimInf is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,7 +39,8 @@
  * pressure phi among proximal nodes.
  * @return The contribution from neighbors to phi in node i
  */
-double attribute_hidden SimInf_local_spread(
+double attribute_hidden
+SimInf_local_spread(
     const double *neighbors,
     const double *phi,
     const int *u,
