@@ -5,7 +5,7 @@
  * Copyright (C) 2015 Pavol Bauer
  * Copyright (C) 2017 -- 2019 Robin Eriksson
  * Copyright (C) 2015 -- 2019 Stefan Engblom
- * Copyright (C) 2015 -- 2020 Stefan Widgren
+ * Copyright (C) 2015 -- 2022 Stefan Widgren
  *
  * SimInf is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,7 +47,8 @@ enum {UPSILON_1, UPSILON_2, UPSILON_3, GAMMA_1, GAMMA_2, GAMMA_3,
  * @param t Current time.
  * @return propensity.
  */
-static double SISe3_S_1_to_I_1(
+static double
+SISe3_S_1_to_I_1(
     const int *u,
     const double *v,
     const double *ldata,
@@ -70,7 +71,8 @@ static double SISe3_S_1_to_I_1(
  * @param t Current time.
  * @return propensity.
  */
-static double SISe3_S_2_to_I_2(
+static double
+SISe3_S_2_to_I_2(
     const int *u,
     const double *v,
     const double *ldata,
@@ -93,7 +95,8 @@ static double SISe3_S_2_to_I_2(
  * @param t Current time.
  * @return propensity.
  */
-static double SISe3_S_3_to_I_3(
+static double
+SISe3_S_3_to_I_3(
     const int *u,
     const double *v,
     const double *ldata,
@@ -116,7 +119,8 @@ static double SISe3_S_3_to_I_3(
  * @param t Current time.
  * @return propensity.
  */
-static double SISe3_I_1_to_S_1(
+static double
+SISe3_I_1_to_S_1(
     const int *u,
     const double *v,
     const double *ldata,
@@ -140,7 +144,8 @@ static double SISe3_I_1_to_S_1(
  * @param t Current time.
  * @return propensity.
  */
-static double SISe3_I_2_to_S_2(
+static double
+SISe3_I_2_to_S_2(
     const int *u,
     const double *v,
     const double *ldata,
@@ -164,7 +169,8 @@ static double SISe3_I_2_to_S_2(
  * @param t Current time.
  * @return propensity
  */
-static double SISe3_I_3_to_S_3(
+static double
+SISe3_I_3_to_S_3(
     const int *u,
     const double *v,
     const double *ldata,
@@ -193,7 +199,8 @@ static double SISe3_I_3_to_S_3(
  * transition rates, or 0 when it doesn't need to update the
  * transition rates.
  */
-static int SISe3_post_time_step(
+static int
+SISe3_post_time_step(
     double *v_new,
     const int *u,
     const double *v,
@@ -235,7 +242,10 @@ static int SISe3_post_time_step(
  * @param solver The numerical solver.
  * @return The simulated trajectory.
  */
-SEXP attribute_hidden SISe3_run(SEXP model, SEXP solver)
+SEXP attribute_hidden
+SISe3_run(
+    SEXP model,
+    SEXP solver)
 {
     TRFun tr_fun[] = {&SISe3_S_1_to_I_1, &SISe3_I_1_to_S_1,
                       &SISe3_S_2_to_I_2, &SISe3_I_2_to_S_2,
