@@ -36,7 +36,8 @@
  *
  * @return 0 if Ok, else error code.
  */
-static int SimInf_solver_ssm(
+static int
+SimInf_solver_ssm(
     SimInf_compartment_model *model,
     SimInf_scheduled_events *events)
 {
@@ -316,7 +317,9 @@ static int SimInf_solver_ssm(
  * @param args Structure with data for the solver.
  * @return 0 if Ok, else error code.
  */
-int attribute_hidden SimInf_run_solver_ssm(SimInf_solver_args *args)
+int attribute_hidden
+SimInf_run_solver_ssm(
+    SimInf_solver_args *args)
 {
     int error = 0;
     gsl_rng *rng = NULL;
